==> pyvistaqt-0.3.0.tar.gz: pyvistaqt-0.3.0/setup.py <==
"""
Installation file for python pyvistaqt module
"""
import os
from io import open as io_open

from setuptools import setup

package_name = 'pyvistaqt'

__version__ = None
filepath = os.path.dirname(__file__)
version_file = os.path.join(filepath, package_name, '_version.py')
with io_open(version_file, mode='r') as fd:
    exec(fd.read())

readme_file = os.path.join(filepath, 'README.rst')

setup(
    name=package_name,
    packages=[package_name, package_name],
    version=__version__,
    description='pyvista qt plotter',
    long_description=io_open(readme_file, encoding="utf-8").read(),
    author='PyVista Developers',
    author_email='info@pyvista.org',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],

    url='https://github.com/pyvista/pyvistaqt',
    keywords='vtk numpy plotting mesh qt pyqt',
    python_requires='>=3.6.*',
    install_requires=['pyvista>=0.25.0',
                      'QtPy>=1.9.0',
                      'PyQt5>=5.11.3'
                      'imageio>=2.5.0',
    ],
    package_data={'pyvistaqt': [
        os.path.join('data', '*.png'),
    ]}

)

==> pyvistaqt-0.10.0.tar.gz: pyvistaqt-0.10.0/setup.py <==
"""
Installation file for python pyvistaqt module
"""
import os
from pathlib import Path
from io import open as io_open

from setuptools import setup

package_name = 'pyvistaqt'
readme_file = Path(__file__).parent / 'README.rst'

setup(
    name=package_name,
    packages=[package_name, package_name],
    description='pyvista qt plotter',
    long_description=readme_file.read_text(),
    long_description_content_type='text/x-rst',
    author='PyVista Developers',
    author_email='info@pyvista.org',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],

    url='https://github.com/pyvista/pyvistaqt',
    keywords='vtk numpy plotting mesh qt',
    python_requires='>=3.7',
    setup_requires=["setuptools>=45", "setuptools_scm>=6.2"],
    use_scm_version={
        "write_to": "pyvistaqt/_version.py",
        "version_scheme": "release-branch-semver",
    },
    install_requires=[
        'pyvista>=0.32.0',
        'QtPy>=1.9.0',
        "importlib_resources>=5.10.2; python_version<'3.9'",
    ],
    package_data={'pyvistaqt': [
        os.path.join('data', '*.png'),
    ]}

)
